QrBeepStream enum

Stream de áudio do Android em que o beep toca.

O volume de cada stream é controlado separadamente no aparelho.

Inheritance
Available extensions

Values

music → const QrBeepStream

Volume de mídia (padrão).

alarm → const QrBeepStream

Volume de alarme — independente do de mídia; num totem é mais difícil de silenciar por acidente.

notification → const QrBeepStream

Volume de notificações.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<QrBeepStream>
A constant List of the values in this enum, in order of their declaration.